@@ -57,7 +57,7 @@ if(exists("v0")){
 	fv[v0] <- 1/diff(v)[v0]
 	}
 else{
-	f<-WGVmix(y,id,w, rtol = rtol, verb=verb)
+	f<-WGVmix(y,id,w, pv = pv, rtol = rtol, verb=verb)
 	fv<-f$y
 	}
 
